@import url(https://fonts.googleapis.com/css?family=Material+Icons);
@import url(https://fonts.googleapis.com/css?family=Open+Sans);
@import url(https://fonts.googleapis.com/css?family=Roboto+Mono);
@import url(https://fonts.googleapis.com/css?family=Orbitron);
/******************************************************************************
 *
 * Copyright (c) 2017, the Perspective Authors.
 *
 * This file is part of the Perspective library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
.perspective-viewer-material {
  font-family: "Open Sans";
  --interface--font-family: "Open Sans";
  --interface-monospace--font-family: "Roboto Mono";
  --inactive-column-selector--content: "\E835";
  --active-column-selector--content: "\E834";
  --column--background: none;
  --column--height: 21px;
  --active-column--height: 51px;
  --inactive-column--height: 24px;
  --active-columns--justify-content: space-evenly;
  --inactive-column--opacity: 0.3;
  --float--column-type--color: #1a7da1;
  --string--column-type--color: #ff8888;
  --settings-button--content: "more_vert";
  --button--font-family: "Material Icons";
  --overflow_hint--before: "error_outline";
  --overflow_hint--font-family: "Material Icons";
  --overflow_hint--color: rgba(0, 0, 0, 0.2);
  --overflow_hint--padding: 0 12px 0 6px;
  --copy_button--before: "file_copy";
  --download_button--before: "save_alt";
  --reset_button--before: "refresh";
  --row_draggable-border-last-child-width: 0;
  --row_pivots--before: "Group By";
  --column_pivots--before: "Split By";
  --sort-order-asc--before: "arrow_upward";
  --sort-order-desc--before: "arrow_downward";
  --sort-order-none--before: "remove";
  --close_button--before: "close";
  --sort-order-col-asc--before: "arrow_back";
  --sort-order-col-desc--before: "arrow_forward";
  --select--background-color: none;
  --select--padding: 0px;
  --column-drop-container--background: none;
  --column-drop-container--padding: 0px;
  --column-drop-container--margin: 24px 24px 0px 0px;
  --column-drop-label--margin: -12px 0px 0px 0px;
  --column-drop-label--font-size: 10px;
  --column-drop-label--display: inline-block;
  --column-container--margin: 24px 0px 0px 0px;
  --column-add--font-family: "Material Icons";
  --column-add--before: "add";
  --column-close--font-family: "Material Icons";
  --column-close--before: "close";
  --column_type--padding: 0px 0px 0px 0px;
  --column_type--width: 25px;
  --column-selector--font-family: "Material Icons";
  --active-column-selector--height: 45px;
  --column_selector--width: 31px;
  --column_selector--font-size: 16px;
  --hypergrid-gridline--color: #ddd;
  --hypergrid--padding: 24px;
  --side_panel--padding: 24px 24px 24px 17px;
  --button--padding: 24px 17px 0px 17px;
  --button--font-size: 16px;
  --top_panel--padding: 0px 0px 24px 0px;
  --top-panel-row--display: inline-flex;
  --hypergrid-scrollbar--width: 8px;
  --hypergrid-scrollbar--border-radius: 5px;
  --hypergrid--font-size: 12px;
  --hypergrid-header--font-size: 12px;
  --hypergrid--font-family: "Open Sans";
  --hypergrid-header--font-family: "Open Sans";
  --d3fc-treedata-axis--lines: none;
  --active--color: #1a7da1;
  --hypergrid--color: #666;
  --hypergrid--background: #fff;
  --hypergrid-positive--color: #1078d1;
  --hypergrid-negative--color: #de3838;
  --hypergrid-selection--background: rgba(0, 0, 0, 0.1);
}
.perspective-viewer-material-dark {
  font-family: "Open Sans";
  --interface--font-family: "Open Sans";
  --interface-monospace--font-family: "Roboto Mono";
  --inactive-column-selector--content: "\E835";
  --active-column-selector--content: "\E834";
  --column--background: none;
  --column--height: 21px;
  --active-column--height: 51px;
  --inactive-column--height: 24px;
  --active-columns--justify-content: space-evenly;
  --inactive-column--opacity: 0.3;
  --float--column-type--color: #1a7da1;
  --string--column-type--color: #ff8888;
  --settings-button--content: "more_vert";
  --button--font-family: "Material Icons";
  --overflow_hint--before: "error_outline";
  --overflow_hint--font-family: "Material Icons";
  --overflow_hint--color: rgba(0, 0, 0, 0.2);
  --overflow_hint--padding: 0 12px 0 6px;
  --copy_button--before: "file_copy";
  --download_button--before: "save_alt";
  --reset_button--before: "refresh";
  --row_draggable-border-last-child-width: 0;
  --row_pivots--before: "Group By";
  --column_pivots--before: "Split By";
  --sort-order-asc--before: "arrow_upward";
  --sort-order-desc--before: "arrow_downward";
  --sort-order-none--before: "remove";
  --close_button--before: "close";
  --sort-order-col-asc--before: "arrow_back";
  --sort-order-col-desc--before: "arrow_forward";
  --select--background-color: none;
  --select--padding: 0px;
  --column-drop-container--background: none;
  --column-drop-container--padding: 0px;
  --column-drop-container--margin: 24px 24px 0px 0px;
  --column-drop-label--margin: -12px 0px 0px 0px;
  --column-drop-label--font-size: 10px;
  --column-drop-label--display: inline-block;
  --column-container--margin: 24px 0px 0px 0px;
  --column-add--font-family: "Material Icons";
  --column-add--before: "add";
  --column-close--font-family: "Material Icons";
  --column-close--before: "close";
  --column_type--padding: 0px 0px 0px 0px;
  --column_type--width: 25px;
  --column-selector--font-family: "Material Icons";
  --active-column-selector--height: 45px;
  --column_selector--width: 31px;
  --column_selector--font-size: 16px;
  --hypergrid-gridline--color: #ddd;
  --hypergrid--padding: 24px;
  --side_panel--padding: 24px 24px 24px 17px;
  --button--padding: 24px 17px 0px 17px;
  --button--font-size: 16px;
  --top_panel--padding: 0px 0px 24px 0px;
  --top-panel-row--display: inline-flex;
  --hypergrid-scrollbar--width: 8px;
  --hypergrid-scrollbar--border-radius: 5px;
  --hypergrid--font-size: 12px;
  --hypergrid-header--font-size: 12px;
  --hypergrid--font-family: "Open Sans";
  --hypergrid-header--font-family: "Open Sans";
  --d3fc-treedata-axis--lines: none;
  background-color: #2a2c2f;
  color: #cfd8dc;
  --background-color: #2a2c2f;
  --color: #cfd8dc;
  --plugin--background: #2f3136;
  --select--background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCEtLSBHZW5lcmF0b3I6IEFkb2JlIElsbHVzdHJhdG9yIDIwLjAuMCwgU1ZHIEV4cG9ydCBQbHVnLUluIC4gU1ZHIFZlcnNpb246IDYuMDAgQnVpbGQgMCkgIC0tPgo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4IgoJIHZpZXdCb3g9IjAgMCA0LjkgMTAiIHN0eWxlPSJlbmFibGUtYmFja2dyb3VuZDpuZXcgMCAwIDQuOSAxMDsiIHhtbDpzcGFjZT0icHJlc2VydmUiPgo8c3R5bGUgdHlwZT0idGV4dC9jc3MiPgoJLnN0MHtmaWxsOiM0NDQ0NDQ7fQo8L3N0eWxlPgo8dGl0bGU+YXJyb3dzPC90aXRsZT4KPHBvbHlnb24gY2xhc3M9InN0MCIgcG9pbnRzPSIxLjQsNC43IDIuNSwzLjIgMy41LDQuNyAiLz4KPHBvbHlnb24gY2xhc3M9InN0MCIgcG9pbnRzPSIzLjUsNS4zIDIuNSw2LjggMS40LDUuMyAiLz4KPC9zdmc+Cg==) no-repeat 95% 50%;
  --inactive--color: #666;
  --active--background: #135d78;
  --active--color: #22a0ce;
  --column_type-float--color: #22a0ce;
  --column_type-string--color: #ff8888;
  --hypergrid--color: #eee;
  --hypergrid-tree-header--background: #2f3136;
  --hypergrid--background: #2f3136;
  --hypergrid-tree-header--color: #eee;
  --hypergrid-header--background: #2f3136;
  --hypergrid-separator--color: #eee;
  --hypergrid-header--color: #eee;
  --hypergrid-selection--background: rgba(255, 255, 255, 0.25);
  --hypergrid-positive--color: #22a0ce;
  --hypergrid-negative--color: #ff8888;
  --expression--operator-color: #cfd8dc;
  --expression--function-color: #22a0ce;
  --expression--error-color: #ff8888;
  --hypergrid-row-hover--background: #555;
  --hypergrid-row-hover--color: #eee;
  --hypergrid-cell-hover--background: #444;
  --hypergrid-cell-hover--color: #eee;
  --highcharts-label--fill: #cfd8dc;
  --highcharts-rect--opacity: 0.85;
  --highcharts-grid-line--stroke: #3b3f46;
  --highcharts-tooltip--background: #2a2c2f;
  --d3fc-legend--text: #bbbbbb;
  --d3fc-treedata--labels: #bbbbbb;
  --d3fc-treedata--hover-highlight: #ffffff;
  --d3fc-axis--ticks: #bbbbbb;
  --d3fc-axis--lines: #555555;
  --d3fc-tooltip--background: #333333;
  --d3fc-tooltip--color: #cfd8dc;
  --d3fc-series: rgba(31, 119, 180, 0.8);
  --d3fc-series-1: #0366d6;
  --d3fc-series-2: #ff7f0e;
  --d3fc-series-3: #2ca02c;
  --d3fc-series-4: #d62728;
  --d3fc-series-5: #9467bd;
  --d3fc-series-6: #8c564b;
  --d3fc-series-7: #e377c2;
  --d3fc-series-8: #7f7f7f;
  --d3fc-series-9: #bcbd22;
  --d3fc-series-10: #17becf;
  --d3fc-full--gradient: linear-gradient(#feeb65 0%, #e4521b 22.5%, #4d342f 42.5%, #222222 50%, #1a237e 57.5%, #42b3d5 67.5%, #dcedc8 100%);
  --d3fc-positive--gradient: linear-gradient(#222222 0%, #1a237e 35%, #42b3d5 70%, #dcedc8 100%);
  --d3fc-negative--gradient: linear-gradient(#feeb65 0%, #e4521b 35%, #4d342f 70%, #222222 100%);
  --highcharts-full--gradient: linear-gradient(#feeb65 0%, #e4521b 22.5%, #4d342f 42.5%, #222222 50%, #1a237e 57.5%, #42b3d5 67.5%, #dcedc8 100%);
  --highcharts-positive--gradient: linear-gradient(#222222 0%, #1a237e 35%, #42b3d5 70%, #dcedc8 100%);
  --highcharts-negative--gradient: linear-gradient(#feeb65 0%, #e4521b 35%, #4d342f 70%, #222222 100%);
  --warning--color: #333;
  --autocomplete-select-background: #555;
  --autocomplete-hover-background: #444;
}
.perspective-viewer-material-dark table {
  color: #cfd8dc;
}
.perspective-viewer-material-dark tr td span.pd-tree-group {
  border-left: 1px solid #444;
}
.perspective-viewer-material-dark tr td.pd-group-header,
.perspective-viewer-material-dark tr th.pd-group-header {
  border-right: 1px solid #999;
}
.perspective-viewer-material-dark tr:last-child th {
  border-bottom: 1px solid #999;
}
.perspective-viewer-material-dark .pd-selected td {
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dark tr.pd-selected:hover td div {
  background-color: #444;
}
.perspective-viewer-material-dark td.pd-negative {
  color: #ff8888;
}
.perspective-viewer-material-dark td.pd-positive {
  color: #22a0ce;
}
.perspective-viewer-material-dark .pd-selected td:not(.pd-group-header),
.perspective-viewer-material-dark .pd-selected td span.pd-group-name {
  background: #EA7319 !important;
}
.perspective-viewer-material-dark .pd-selected td {
  color: #000;
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dark .pd-sub-selected td:not(.pd-group-header),
.perspective-viewer-material-dark .pd-sub-selected td span.pd-group-name {
  background: rgba(234, 115, 25, 0.2) !important;
}
.perspective-viewer-material-dark tbody:hover tr:hover td,
.perspective-viewer-material-dark tbody:hover tr:hover td span {
  background: #444;
}
.perspective-viewer-material-dark table tr:hover {
  color: #ffffff;
}
.perspective-viewer-material-dense {
  font-family: "Open Sans";
  --interface--font-family: "Open Sans";
  --interface-monospace--font-family: "Roboto Mono";
  --inactive-column-selector--content: "\E835";
  --active-column-selector--content: "\E834";
  --column--background: none;
  --column--height: 21px;
  --active-column--height: 51px;
  --inactive-column--height: 24px;
  --active-columns--justify-content: space-evenly;
  --inactive-column--opacity: 0.3;
  --float--column-type--color: #1a7da1;
  --string--column-type--color: #ff8888;
  --settings-button--content: "more_vert";
  --button--font-family: "Material Icons";
  --overflow_hint--before: "error_outline";
  --overflow_hint--font-family: "Material Icons";
  --overflow_hint--color: rgba(0, 0, 0, 0.2);
  --overflow_hint--padding: 0 12px 0 6px;
  --copy_button--before: "file_copy";
  --download_button--before: "save_alt";
  --reset_button--before: "refresh";
  --row_draggable-border-last-child-width: 0;
  --row_pivots--before: "Group By";
  --column_pivots--before: "Split By";
  --sort-order-asc--before: "arrow_upward";
  --sort-order-desc--before: "arrow_downward";
  --sort-order-none--before: "remove";
  --close_button--before: "close";
  --sort-order-col-asc--before: "arrow_back";
  --sort-order-col-desc--before: "arrow_forward";
  --select--background-color: none;
  --select--padding: 0px;
  --column-drop-container--background: none;
  --column-drop-container--padding: 0px;
  --column-drop-container--margin: 24px 24px 0px 0px;
  --column-drop-label--margin: -12px 0px 0px 0px;
  --column-drop-label--font-size: 10px;
  --column-drop-label--display: inline-block;
  --column-container--margin: 24px 0px 0px 0px;
  --column-add--font-family: "Material Icons";
  --column-add--before: "add";
  --column-close--font-family: "Material Icons";
  --column-close--before: "close";
  --column_type--padding: 0px 0px 0px 0px;
  --column_type--width: 25px;
  --column-selector--font-family: "Material Icons";
  --active-column-selector--height: 45px;
  --column_selector--width: 31px;
  --column_selector--font-size: 16px;
  --hypergrid-gridline--color: #ddd;
  --hypergrid--padding: 24px;
  --side_panel--padding: 24px 24px 24px 17px;
  --button--padding: 24px 17px 0px 17px;
  --button--font-size: 16px;
  --top_panel--padding: 0px 0px 24px 0px;
  --top-panel-row--display: inline-flex;
  --hypergrid-scrollbar--width: 8px;
  --hypergrid-scrollbar--border-radius: 5px;
  --hypergrid--font-size: 12px;
  --hypergrid-header--font-size: 12px;
  --hypergrid--font-family: "Open Sans";
  --hypergrid-header--font-family: "Open Sans";
  --d3fc-treedata-axis--lines: none;
  --active--color: #1a7da1;
  --hypergrid--color: #666;
  --hypergrid--background: #fff;
  --hypergrid-positive--color: #1078d1;
  --hypergrid-negative--color: #de3838;
  --hypergrid-selection--background: rgba(0, 0, 0, 0.1);
  --hypergrid--padding: 12px 12px 12px 12px;
  --hypergrid-row--height: 20px;
  --side_panel--padding: 12px 12px 12px 10px;
  --top_panel--padding: 0px 0px 12px 0px;
  --column-drop-label--margin: -10px 0px 0px 0px;
  --column-drop-container--margin: 12px 12px 0px 0px;
  --column-container--margin: 12px 0px 0px 0px;
  --row_draggable--animation: none;
  --button--padding: 12px 9px;
  --active-column--height: 45px;
  --column-drop-label--font-size: 8px;
  --column_selector--width: 24px;
}
.perspective-viewer-material-dense-dark {
  font-family: "Open Sans";
  --interface--font-family: "Open Sans";
  --interface-monospace--font-family: "Roboto Mono";
  --inactive-column-selector--content: "\E835";
  --active-column-selector--content: "\E834";
  --column--background: none;
  --column--height: 21px;
  --active-column--height: 51px;
  --inactive-column--height: 24px;
  --active-columns--justify-content: space-evenly;
  --inactive-column--opacity: 0.3;
  --float--column-type--color: #1a7da1;
  --string--column-type--color: #ff8888;
  --settings-button--content: "more_vert";
  --button--font-family: "Material Icons";
  --overflow_hint--before: "error_outline";
  --overflow_hint--font-family: "Material Icons";
  --overflow_hint--color: rgba(0, 0, 0, 0.2);
  --overflow_hint--padding: 0 12px 0 6px;
  --copy_button--before: "file_copy";
  --download_button--before: "save_alt";
  --reset_button--before: "refresh";
  --row_draggable-border-last-child-width: 0;
  --row_pivots--before: "Group By";
  --column_pivots--before: "Split By";
  --sort-order-asc--before: "arrow_upward";
  --sort-order-desc--before: "arrow_downward";
  --sort-order-none--before: "remove";
  --close_button--before: "close";
  --sort-order-col-asc--before: "arrow_back";
  --sort-order-col-desc--before: "arrow_forward";
  --select--background-color: none;
  --select--padding: 0px;
  --column-drop-container--background: none;
  --column-drop-container--padding: 0px;
  --column-drop-container--margin: 24px 24px 0px 0px;
  --column-drop-label--margin: -12px 0px 0px 0px;
  --column-drop-label--font-size: 10px;
  --column-drop-label--display: inline-block;
  --column-container--margin: 24px 0px 0px 0px;
  --column-add--font-family: "Material Icons";
  --column-add--before: "add";
  --column-close--font-family: "Material Icons";
  --column-close--before: "close";
  --column_type--padding: 0px 0px 0px 0px;
  --column_type--width: 25px;
  --column-selector--font-family: "Material Icons";
  --active-column-selector--height: 45px;
  --column_selector--width: 31px;
  --column_selector--font-size: 16px;
  --hypergrid-gridline--color: #ddd;
  --hypergrid--padding: 24px;
  --side_panel--padding: 24px 24px 24px 17px;
  --button--padding: 24px 17px 0px 17px;
  --button--font-size: 16px;
  --top_panel--padding: 0px 0px 24px 0px;
  --top-panel-row--display: inline-flex;
  --hypergrid-scrollbar--width: 8px;
  --hypergrid-scrollbar--border-radius: 5px;
  --hypergrid--font-size: 12px;
  --hypergrid-header--font-size: 12px;
  --hypergrid--font-family: "Open Sans";
  --hypergrid-header--font-family: "Open Sans";
  --d3fc-treedata-axis--lines: none;
  background-color: #2a2c2f;
  color: #cfd8dc;
  --background-color: #2a2c2f;
  --color: #cfd8dc;
  --plugin--background: #2f3136;
  --select--background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCEtLSBHZW5lcmF0b3I6IEFkb2JlIElsbHVzdHJhdG9yIDIwLjAuMCwgU1ZHIEV4cG9ydCBQbHVnLUluIC4gU1ZHIFZlcnNpb246IDYuMDAgQnVpbGQgMCkgIC0tPgo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4IgoJIHZpZXdCb3g9IjAgMCA0LjkgMTAiIHN0eWxlPSJlbmFibGUtYmFja2dyb3VuZDpuZXcgMCAwIDQuOSAxMDsiIHhtbDpzcGFjZT0icHJlc2VydmUiPgo8c3R5bGUgdHlwZT0idGV4dC9jc3MiPgoJLnN0MHtmaWxsOiM0NDQ0NDQ7fQo8L3N0eWxlPgo8dGl0bGU+YXJyb3dzPC90aXRsZT4KPHBvbHlnb24gY2xhc3M9InN0MCIgcG9pbnRzPSIxLjQsNC43IDIuNSwzLjIgMy41LDQuNyAiLz4KPHBvbHlnb24gY2xhc3M9InN0MCIgcG9pbnRzPSIzLjUsNS4zIDIuNSw2LjggMS40LDUuMyAiLz4KPC9zdmc+Cg==) no-repeat 95% 50%;
  --inactive--color: #666;
  --active--background: #135d78;
  --active--color: #22a0ce;
  --column_type-float--color: #22a0ce;
  --column_type-string--color: #ff8888;
  --hypergrid--color: #eee;
  --hypergrid-tree-header--background: #2f3136;
  --hypergrid--background: #2f3136;
  --hypergrid-tree-header--color: #eee;
  --hypergrid-header--background: #2f3136;
  --hypergrid-separator--color: #eee;
  --hypergrid-header--color: #eee;
  --hypergrid-selection--background: rgba(255, 255, 255, 0.25);
  --hypergrid-positive--color: #22a0ce;
  --hypergrid-negative--color: #ff8888;
  --expression--operator-color: #cfd8dc;
  --expression--function-color: #22a0ce;
  --expression--error-color: #ff8888;
  --hypergrid-row-hover--background: #555;
  --hypergrid-row-hover--color: #eee;
  --hypergrid-cell-hover--background: #444;
  --hypergrid-cell-hover--color: #eee;
  --highcharts-label--fill: #cfd8dc;
  --highcharts-rect--opacity: 0.85;
  --highcharts-grid-line--stroke: #3b3f46;
  --highcharts-tooltip--background: #2a2c2f;
  --d3fc-legend--text: #bbbbbb;
  --d3fc-treedata--labels: #bbbbbb;
  --d3fc-treedata--hover-highlight: #ffffff;
  --d3fc-axis--ticks: #bbbbbb;
  --d3fc-axis--lines: #555555;
  --d3fc-tooltip--background: #333333;
  --d3fc-tooltip--color: #cfd8dc;
  --d3fc-series: rgba(31, 119, 180, 0.8);
  --d3fc-series-1: #0366d6;
  --d3fc-series-2: #ff7f0e;
  --d3fc-series-3: #2ca02c;
  --d3fc-series-4: #d62728;
  --d3fc-series-5: #9467bd;
  --d3fc-series-6: #8c564b;
  --d3fc-series-7: #e377c2;
  --d3fc-series-8: #7f7f7f;
  --d3fc-series-9: #bcbd22;
  --d3fc-series-10: #17becf;
  --d3fc-full--gradient: linear-gradient(#feeb65 0%, #e4521b 22.5%, #4d342f 42.5%, #222222 50%, #1a237e 57.5%, #42b3d5 67.5%, #dcedc8 100%);
  --d3fc-positive--gradient: linear-gradient(#222222 0%, #1a237e 35%, #42b3d5 70%, #dcedc8 100%);
  --d3fc-negative--gradient: linear-gradient(#feeb65 0%, #e4521b 35%, #4d342f 70%, #222222 100%);
  --highcharts-full--gradient: linear-gradient(#feeb65 0%, #e4521b 22.5%, #4d342f 42.5%, #222222 50%, #1a237e 57.5%, #42b3d5 67.5%, #dcedc8 100%);
  --highcharts-positive--gradient: linear-gradient(#222222 0%, #1a237e 35%, #42b3d5 70%, #dcedc8 100%);
  --highcharts-negative--gradient: linear-gradient(#feeb65 0%, #e4521b 35%, #4d342f 70%, #222222 100%);
  --warning--color: #333;
  --autocomplete-select-background: #555;
  --autocomplete-hover-background: #444;
  --hypergrid--padding: 12px 12px 12px 12px;
  --hypergrid-row--height: 20px;
  --side_panel--padding: 12px 12px 12px 10px;
  --top_panel--padding: 0px 0px 12px 0px;
  --column-drop-label--margin: -10px 0px 0px 0px;
  --column-drop-container--margin: 12px 12px 0px 0px;
  --column-container--margin: 12px 0px 0px 0px;
  --row_draggable--animation: none;
  --button--padding: 12px 9px;
  --active-column--height: 45px;
  --column-drop-label--font-size: 8px;
  --column_selector--width: 24px;
}
.perspective-viewer-material-dense-dark table {
  color: #cfd8dc;
}
.perspective-viewer-material-dense-dark tr td span.pd-tree-group {
  border-left: 1px solid #444;
}
.perspective-viewer-material-dense-dark tr td.pd-group-header,
.perspective-viewer-material-dense-dark tr th.pd-group-header {
  border-right: 1px solid #999;
}
.perspective-viewer-material-dense-dark tr:last-child th {
  border-bottom: 1px solid #999;
}
.perspective-viewer-material-dense-dark .pd-selected td {
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dense-dark tr.pd-selected:hover td div {
  background-color: #444;
}
.perspective-viewer-material-dense-dark td.pd-negative {
  color: #ff8888;
}
.perspective-viewer-material-dense-dark td.pd-positive {
  color: #22a0ce;
}
.perspective-viewer-material-dense-dark .pd-selected td:not(.pd-group-header),
.perspective-viewer-material-dense-dark .pd-selected td span.pd-group-name {
  background: #EA7319 !important;
}
.perspective-viewer-material-dense-dark .pd-selected td {
  color: #000;
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dense-dark .pd-sub-selected td:not(.pd-group-header),
.perspective-viewer-material-dense-dark .pd-sub-selected td span.pd-group-name {
  background: rgba(234, 115, 25, 0.2) !important;
}
.perspective-viewer-material-dense-dark tbody:hover tr:hover td,
.perspective-viewer-material-dense-dark tbody:hover tr:hover td span {
  background: #444;
}
.perspective-viewer-material-dense-dark table tr:hover {
  color: #ffffff;
}
.perspective-viewer-material-dense-dark table {
  color: #cfd8dc;
}
.perspective-viewer-material-dense-dark tr td span.pd-tree-group {
  border-left: 1px solid #444;
}
.perspective-viewer-material-dense-dark tr td.pd-group-header,
.perspective-viewer-material-dense-dark tr th.pd-group-header {
  border-right: 1px solid #999;
}
.perspective-viewer-material-dense-dark tr:last-child th {
  border-bottom: 1px solid #999;
}
.perspective-viewer-material-dense-dark .pd-selected td {
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dense-dark tr.pd-selected:hover td div {
  background-color: #444;
}
.perspective-viewer-material-dense-dark td.pd-negative {
  color: #ff8888;
}
.perspective-viewer-material-dense-dark td.pd-positive {
  color: #22a0ce;
}
.perspective-viewer-material-dense-dark .pd-selected td:not(.pd-group-header),
.perspective-viewer-material-dense-dark .pd-selected td span.pd-group-name {
  background: #EA7319 !important;
}
.perspective-viewer-material-dense-dark .pd-selected td {
  color: #000;
  background-color: rgba(0, 0, 0, 0);
}
.perspective-viewer-material-dense-dark .pd-sub-selected td:not(.pd-group-header),
.perspective-viewer-material-dense-dark .pd-sub-selected td span.pd-group-name {
  background: rgba(234, 115, 25, 0.2) !important;
}
.perspective-viewer-material-dense-dark tbody:hover tr:hover td,
.perspective-viewer-material-dense-dark tbody:hover tr:hover td span {
  background: #444;
}
.perspective-viewer-material-dense-dark table tr:hover {
  color: #ffffff;
}
.perspective-viewer-vaporwave {
  font-family: "Open Sans";
  --interface--font-family: "Open Sans";
  --interface-monospace--font-family: "Roboto Mono";
  --inactive-column-selector--content: "\E835";
  --active-column-selector--content: "\E834";
  --column--background: none;
  --column--height: 21px;
  --active-column--height: 51px;
  --inactive-column--height: 24px;
  --active-columns--justify-content: space-evenly;
  --inactive-column--opacity: 0.3;
  --float--column-type--color: #1a7da1;
  --string--column-type--color: #ff8888;
  --settings-button--content: "more_vert";
  --button--font-family: "Material Icons";
  --overflow_hint--before: "error_outline";
  --overflow_hint--font-family: "Material Icons";
  --overflow_hint--color: rgba(0, 0, 0, 0.2);
  --overflow_hint--padding: 0 12px 0 6px;
  --copy_button--before: "file_copy";
  --download_button--before: "save_alt";
  --reset_button--before: "refresh";
  --row_draggable-border-last-child-width: 0;
  --row_pivots--before: "Group By";
  --column_pivots--before: "Split By";
  --sort-order-asc--before: "arrow_upward";
  --sort-order-desc--before: "arrow_downward";
  --sort-order-none--before: "remove";
  --close_button--before: "close";
  --sort-order-col-asc--before: "arrow_back";
  --sort-order-col-desc--before: "arrow_forward";
  --select--background-color: none;
  --select--padding: 0px;
  --column-drop-container--background: none;
  --column-drop-container--padding: 0px;
  --column-drop-container--margin: 24px 24px 0px 0px;
  --column-drop-label--margin: -12px 0px 0px 0px;
  --column-drop-label--font-size: 10px;
  --column-drop-label--display: inline-block;
  --column-container--margin: 24px 0px 0px 0px;
  --column-add--font-family: "Material Icons";
  --column-add--before: "add";
  --column-close--font-family: "Material Icons";
  --column-close--before: "close";
  --column_type--padding: 0px 0px 0px 0px;
  --column_type--width: 25px;
  --column-selector--font-family: "Material Icons";
  --active-column-selector--height: 45px;
  --column_selector--width: 31px;
  --column_selector--font-size: 16px;
  --hypergrid-gridline--color: #ddd;
  --side_panel--padding: 24px 24px 24px 17px;
  --button--padding: 24px 17px 0px 17px;
  --button--font-size: 16px;
  --top_panel--padding: 0px 0px 24px 0px;
  --top-panel-row--display: inline-flex;
  --hypergrid-scrollbar--width: 8px;
  --hypergrid-scrollbar--border-radius: 5px;
  --d3fc-treedata-axis--lines: none;
  padding: 24px;
  background-color: #150442;
  color: #cfd8dc;
  font-family: "Orbitron";
  --active--color: #F4D676;
  --active--border: 1px solid #F4D676;
  --active--background: rgba(244, 214, 118, 0.7);
  --inactive--color: #5C2686;
  --settings-button--content: "check_box_outline_blank";
  --float--column-type--content: "DBL";
  --float--column-type--color: #36CDC4;
  --float--hypergrid--font-family: "Roboto Mono";
  --float--hypergrid--font-size: 12px;
  --float--hypergrid--background: hsl(256, 87%, 14%);
  --float--hypergrid--color: #3c335e;
  --float--hypergrid-positive--color: white;
  --float--hypergrid-positive--background: #36cdc4;
  --float--hypergrid-negative--color: white;
  --float--hypergrid-negative--background: #ff1690;
  --float--hypergrid-positive--border-bottom-color: #24928b;
  --float--hypergrid-positive--border-right-color: #24928b;
  --float--hypergrid-negative--border-bottom-color: #db127a;
  --float--hypergrid-negative--border-right-color: #db127a;
  --integer--column-type--content: "INT";
  --integer--column-type--color: #36CDC4;
  --integer--hypergrid--font-family: "Roboto Mono";
  --integer--hypergrid--font-size: 12px;
  --integer--hypergrid--background: hsl(256, 87%, 14%);
  --integer--hypergrid--color: #3c335e;
  --integer--hypergrid-positive--color: #8bde8b;
  --integer--hypergrid-negative--color: #ff6a8b;
  --string--column-type--content: "STR";
  --string--column-type--color: #FF1690;
  --date--column-type--content: "MDY";
  --datetime--column-type--content: "MDY";
  --plugin--background: #1C0658;
  --plugin--border: 1px solid hsl(256, 87%, 28%);
  --plugin--box-shadow: 0px 10px 10px rgba(0, 0, 0, 0.4);
  --hypergrid-row-hover--background: rgba(0, 0, 0, 0.1);
  --hypergrid-cell-hover--background: rgba(0, 0, 0, 0.2);
  --hypergrid--color: #eee;
  --hypergrid--font-family: "Open Sans";
  --hypergrid-gridline--color: #cfd8dc;
  --active-column-selector--content: "check";
  --hypergrid-header--font-family: "Open Sans";
  --hypergrid--padding: 24px;
  --hypergrid--background: #1C0658;
  --hypergrid-tree-header--background: #1C0658;
  --hypergrid-tree-header--color: #eee;
  --hypergrid-header--background: #1C0658;
  --hypergrid-separator--color: #8BC4EE;
  --hypergrid-header--color: #eee;
  --hypergrid--font-size: 12px;
  --hypergrid-header--font-size: 12px;
  --highcharts-label--fill: #cfd8dc;
  --highcharts-rect--opacity: 0.85;
  --highcharts-tooltip--background: #2a2c2f;
  --d3fc-gridline--color: #5C2686;
  --d3fc-legend--text: #bbbbbb;
  --d3fc-treedata--labels: #bbbbbb;
  --d3fc-treedata--hover-highlight: #ffffff;
  --d3fc-axis--ticks: #bbbbbb;
  --d3fc-axis--lines: #5C2686;
  --d3fc-tooltip--background: #333333;
  --d3fc-tooltip--color: #cfd8dc;
  --d3fc-series: #36CDC4;
  --d3fc-series-1: #FF1690;
  --d3fc-series-2: #36CDC4;
  --d3fc-series-3: #F4D676;
  --d3fc-series-4: #966bff;
  --d3fc-series-5: #C774E8;
  --d3fc-series-6: #FF6AD5;
  --d3fc-series-7: #ff8b8b;
  --d3fc-series-8: #ffde8b;
  --d3fc-series-9: #8bde8b;
  --d3fc-series-10: #20de8b;
  --d3fc-full--gradient: linear-gradient(#f9897b 0%, #d7509f 10%, #f9247e 20%, #ae1357 30%, #661246 40%, #222222 50%, #392682 60%, #7a3a9a 70%, #3f86bc 80%, #28ada8 90%, #83dde0 100%);
  --d3fc-positive--gradient: linear-gradient(#392682 0%, #7a3a9a 25%, #3f86bc 50%, #28ada8 75%, #83dde0 100%);
  --d3fc-negative--gradient: linear-gradient(#f9897b 0%, #d7509f 25%, #f9247e 50%, #ae1357 75%, #661246 100%);
  --highcharts-full--gradient: linear-gradient(#f9897b 0%, #d7509f 10%, #f9247e 20%, #ae1357 30%, #661246 40%, #222222 50%, #392682 60%, #7a3a9a 70%, #3f86bc 80%, #28ada8 90%, #83dde0 100%);
  --highcharts-positive--gradient: linear-gradient(#392682 0%, #7a3a9a 25%, #3f86bc 50%, #28ada8 75%, #83dde0 100%);
  --highcharts-negative--gradient: linear-gradient(#f9897b 0%, #d7509f 25%, #f9247e 50%, #ae1357 75%, #661246 100%);
  --warning--color: #333;
}


/*# sourceMappingURL=all-themes.css.map*/